@@ -12,7 +12,7 @@ require XSLoader;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(minify minify_utf8 minify_ascii);
 
-our $VERSION = 'v0.5.3'; # TRIAL
+our $VERSION = 'v0.5.4'; # TRIAL
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
@@ -35,7 +35,7 @@ Text::Minify::XS - remove indentation and trailing whitespace
 
 =head1 VERSION
 
-version v0.5.3
+version v0.5.4
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ version v0.5.3
 =head1 DESCRIPTION
 
 This is a simple and fast text minifier that removes quickly extra
-whitespace from multi-line UTF-8 text.
+whitespace from multi-line text.
 
 =head1 EXPORTS
 
@@ -84,8 +84,8 @@ and changes carriage returns to newlines.
 It does not recognise any form of markup, comments or text quoting.
 Nor does it remove extra whitespace in the middle of the line.
 
-Because it does not recognise any markup, newlines are removed since
-they may be significant.
+Because it does not recognise any markup, newlines are not removed
+since they may be significant.
 
 =head2 minify_utf8
 
